package com.kdanmobile.android.common.base.view

import android.annotation.SuppressLint
import android.os.Bundle
import androidx.appcompat.app.AppCompatActivity
import com.gyf.immersionbar.ImmersionBar
import com.kdanmobile.android.common.base.ActivitysUtils.finishAllActivitys
import com.kdanmobile.android.common.base.extension.removeAllFragments
import com.kdanmobile.android.common.manager.AppStatusConstant.STATUS_FORCE_KILLED
import com.kdanmobile.android.common.manager.AppStatusConstant.STATUS_NORMAL
import com.kdanmobile.android.common.manager.AppStatusManager
import com.orhanobut.logger.Logger


/**
 * @classname BaseActivity
 * @author LiuXiaoLong
 * @date 2022-07-27
 * @description
 */
open class BaseActivity : AppCompatActivity() {

    //沉浸式状体栏
    @SuppressLint("StaticFieldLeak")
    var mImmersionBar: ImmersionBar? = null

    //标志符号：判断当前activity是否显示
    var isCurrentFront = false

    val handler : BaseActivityHandler by lazy { BaseActivityHandler(this) }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        lifecycle.addObserver(BaseActivityLifecycleEvents(this))
        validateAppStatus()
    }

    override fun onStop() {
        super.onStop()
        if (isFinishing) removeAllFragments()
    }

    private fun validateAppStatus() {
        when (AppStatusManager.appStatus) {
            //异常退出
            STATUS_FORCE_KILLED -> {
                Logger.t("PdfBaseActivity").e("STATUS_FORCE_KILLED")
                refreshApp()
            }
            STATUS_NORMAL -> {
                Logger.t("PdfBaseActivity").e("STATUS_NORMAL")
                //不需要处理或者初始方法调用
            }
        }
    }

    fun refreshApp() {
        //杀掉以前进程
        Logger.t("ActivityUtils").e("refreshApp")
        finishAllActivitys()
    }



}